@@ -18,7 +18,7 @@ class HasProjectPermissions(BasePermission):
     project_token_prefix = 'ProjectToken '
 
     def has_permission(self, view):
-        return True
+        # return True
         token = view.request.headers.get('AUTHORIZATION')
         permission = view.required_project_permission() if hasattr(view, 'required_project_permission') else None
 
@@ -45,8 +45,8 @@ class HasProjectPermissions(BasePermission):
 
             result = project_auth(token, project_token, permission)
 
-            if result.get('warning'):
-                view.headers['X-Application-Warning'] = result['warning']
+            # if result.get('warning'):
+            #     view.headers['X-Application-Warning'] = result['warning']
 
             return result['result']
         elif token[:len(self.project_token_prefix)] == self.project_token_prefix:
@@ -54,8 +54,8 @@ class HasProjectPermissions(BasePermission):
 
             result = project_auth(token, project_token, permission)
 
-            if result.get('warning'):
-                view.headers['X-Application-Warning'] = result['warning']
+            # if result.get('warning'):
+            #     view.headers['X-Application-Warning'] = result['warning']
 
             return result['result']
         else:
