@@ -26,6 +26,9 @@ DATABASE_ONLY = None
 DATABASE_EXCEPT = None
 DATABASE_SCHEMA = None
 
+SSO_APPLICATIONS = {}
+
+ALLOW_ORIGIN = '*'
 
 def set_settings(settings):
     for key, value in settings.items():
